@@ -15,20 +15,18 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
-#include "seahorse-common.h"
-#include "seahorse-util.h"
-
 #include "seahorse-key-manager-store.h"
 #include "seahorse-prefs.h"
 #include "seahorse-validity.h"
+#include "seahorse-util.h"
+
+#include "seahorse-common.h"
 
 #include <string.h>
 #include <unistd.h>
@@ -39,7 +37,7 @@
 #define DEBUG_FLAG SEAHORSE_DEBUG_DRAG
 #include "seahorse-debug.h"
 
-#include "eggtreemultidnd.h"
+#include "libegg/eggtreemultidnd.h"
 
 #define KEY_MANAGER_SORT_KEY "/apps/seahorse/listing/sort_by"
 
