@@ -13,27 +13,29 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
-#include <config.h>
+#include "config.h"
 
-#include <string.h>
+#include "seahorse-search-provider.h"
+
+#include "seahorse-collection.h"
+#include "seahorse-predicate.h"
+#include "seahorse-widget.h"
+#include "seahorse-shell-search-provider-generated.h"
+
+#include "seahorse-common.h"
+
+#include "src/seahorse-key-manager.h"
 
 #include <gcr/gcr.h>
+
 #define SECRET_API_SUBJECT_TO_CHANGE
 #include <libsecret/secret.h>
 
-#include "seahorse-predicate.h"
-#include "seahorse-common.h"
-#include "seahorse-widget.h"
-#include "seahorse-collection.h"
-
-#include "seahorse-shell-search-provider-generated.h"
-#include "seahorse-search-provider.h"
+#include <string.h>
 
 struct _SeahorseSearchProvider {
 	SeahorseShellSearchProvider2Skeleton parent;
@@ -262,8 +264,7 @@ handle_activate_result (SeahorseShellSearchProvider2 *skeleton,
 {
 	SeahorseSearchProvider *self = SEAHORSE_SEARCH_PROVIDER (skeleton);
 	GObject *object;
-	SeahorseWidget *key_manager;
-	GtkWindow *window;
+	SeahorseKeyManager *key_manager;
 
 	sscanf (identifier, "%p", &object);
 
@@ -273,20 +274,8 @@ handle_activate_result (SeahorseShellSearchProvider2 *skeleton,
 		return TRUE;
 	}
 
-	key_manager = seahorse_widget_find ("key-manager");
-	if (key_manager == NULL) {
-		GtkApplication *app;
-
-		app = seahorse_application_get ();
-		g_application_activate (G_APPLICATION (app));
-
-		key_manager = seahorse_widget_find ("key-manager");
-	}
-
-	window = GTK_WINDOW (seahorse_widget_get_widget (key_manager, key_manager->name));
-	gtk_window_present_with_time (window, timestamp);
-
-	seahorse_viewable_view (object, window);
+	key_manager = seahorse_key_manager_show (timestamp);
+	seahorse_viewable_view (object, GTK_WINDOW (key_manager));
 
 	seahorse_shell_search_provider2_complete_activate_result (skeleton,
 	                                                          invocation);
