@@ -14,20 +14,19 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
-#include <config.h>
+#include "config.h"
 
-#include <string.h>
+#include "seahorse-widget.h"
+
+#include "seahorse-common.h"
 
 #include <glib/gi18n.h>
 
-#include "seahorse-common.h"
-#include "seahorse-widget.h"
+#include <string.h>
 
 /**
  * SECTION:seahorse-widget
