@@ -13,10 +13,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -33,10 +31,10 @@
 #include <avahi-glib/glib-malloc.h>
 #endif /* WITH_SHARING */
 
-#include "seahorse-util.h"
+#include "libseahorse/seahorse-util.h"
 
 #define DEBUG_FLAG SEAHORSE_DEBUG_DNSSD
-#include "seahorse-debug.h"
+#include "libseahorse/seahorse-debug.h"
 
 #define HKP_SERVICE_TYPE "_pgpkey-hkp._tcp."
 
