@@ -16,34 +16,33 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
+#include "seahorse-gpgme-key-op.h"
+
+#include "seahorse-gpgme.h"
+#include "seahorse-gpgme-data.h"
+#include "seahorse-gpg-op.h"
+
+#include "libseahorse/seahorse-object-list.h"
+#include "libseahorse/seahorse-progress.h"
+#include "libseahorse/seahorse-util.h"
+
+#define DEBUG_FLAG SEAHORSE_DEBUG_KEYS
+#include "libseahorse/seahorse-debug.h"
+
+#include <glib/gstdio.h>
+#include <glib/gi18n.h>
+
 #include <errno.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
-#include <glib/gstdio.h>
-#include <glib/gi18n.h>
-
-#include "seahorse-object-list.h"
-#include "seahorse-progress.h"
-#include "seahorse-util.h"
-
-#include "pgp/seahorse-gpgme.h"
-#include "pgp/seahorse-gpgme-data.h"
-#include "pgp/seahorse-gpg-op.h"
-#include "pgp/seahorse-gpgme-key-op.h"
-
-#define DEBUG_FLAG SEAHORSE_DEBUG_KEYS
-#include "seahorse-debug.h"
-
 #define PROMPT "keyedit.prompt"
 #define QUIT "quit"
 #define SAVE "keyedit.save.okay"
