@@ -15,9 +15,8 @@
  * Lesser General Public License for more details.
  *  
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.  
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -25,9 +24,10 @@
 #include "seahorse-gpgme.h"
 
 #include "seahorse-common.h"
+
 #define DEBUG_FLAG SEAHORSE_DEBUG_OPERATION
-#include "seahorse-debug.h"
-#include "seahorse-util.h"
+#include "libseahorse/seahorse-debug.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <glib/gi18n.h>
 
